==> jc-1.4.0.tar.gz: soot/jimple/spark/solver/PropMerge__241.h <==
// class soot.jimple.spark.solver.PropMerge$1

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class ac9a90c2da2d45e7 soot_jimple_spark_sets_P2SetVisitor
// @dep_class 7be3b13a8a14d7d6 soot_jimple_spark_solver_PropMerge__241

// header file dependencies
// @dep_header soot_jimple_spark_sets_P2SetVisitor

#include "soot/jimple/spark/sets/P2SetVisitor.h"

#ifndef _JC_soot_jimple_spark_solver_PropMerge__241_H_
#define _JC_soot_jimple_spark_solver_PropMerge__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_FieldRefNode$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;
struct _jc_soot_jimple_spark_solver_PropMerge$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$sub_refs	_jc_soot_jimple_spark_solver_PropMerge__241$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$sub_nonrefs	_jc_soot_jimple_spark_solver_PropMerge__241$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$refs	_jc_soot_jimple_spark_solver_PropMerge__241$refs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$nonrefs	_jc_soot_jimple_spark_solver_PropMerge__241$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$object	_jc_soot_jimple_spark_solver_PropMerge__241$object;

typedef const struct _jc_soot_jimple_spark_solver_PropMerge__241$vmethods	_jc_soot_jimple_spark_solver_PropMerge__241$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropMerge__241$vtable	_jc_soot_jimple_spark_solver_PropMerge__241$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropMerge__241$vtype	_jc_soot_jimple_spark_solver_PropMerge__241$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropMerge__241$method$_init$3d64f0b5c6679344(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge__241$object *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *);

// Virtual methods
extern void _jc_soot_jimple_spark_solver_PropMerge__241$method$visit$29be8db3232dadd5(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge__241$object *, struct _jc_soot_jimple_spark_pag_Node$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropMerge__241$method_info$visit$29be8db3232dadd5;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropMerge__241$vmethods {
	void	(*visit$29be8db3232dadd5)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge__241$object *, struct _jc_soot_jimple_spark_pag_Node$object *);
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropMerge__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	soot_jimple_spark_sets_P2SetVisitor;
	_jc_soot_jimple_spark_solver_PropMerge__241$vmethods	soot_jimple_spark_solver_PropMerge__241;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropMerge__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropMerge__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropMerge__241$sub_refs {
	struct _jc_object	*val__24field;
	struct _jc_soot_jimple_spark_pag_FieldRefNode$object	*val__24fr;
	struct _jc_soot_jimple_spark_solver_PropMerge$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropMerge__241$refs {
    _jc_soot_jimple_spark_solver_PropMerge__241$sub_refs	soot_jimple_spark_solver_PropMerge__241;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropMerge__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropMerge__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_soot_jimple_spark_solver_PropMerge__241$sub_nonrefs	soot_jimple_spark_solver_PropMerge__241;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropMerge__241$object {
	_jc_soot_jimple_spark_solver_PropMerge__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropMerge__241$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropMerge__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropMerge__241$vtype _jc_soot_jimple_spark_solver_PropMerge__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropMerge__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropMerge__241$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropMerge__241_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/spark/solver/PropMerge__241.h <==
// class soot.jimple.spark.solver.PropMerge$1

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class ac9a90c2da2d45e7 soot_jimple_spark_sets_P2SetVisitor
// @dep_class 7be3b13a8a14d7d6 soot_jimple_spark_solver_PropMerge__241

// header file dependencies
// @dep_header soot_jimple_spark_sets_P2SetVisitor

#include "soot/jimple/spark/sets/P2SetVisitor.h"

#ifndef _JC_soot_jimple_spark_solver_PropMerge__241_H_
#define _JC_soot_jimple_spark_solver_PropMerge__241_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_soot_jimple_spark_pag_FieldRefNode$object;
struct _jc_soot_jimple_spark_pag_Node$object;
struct _jc_soot_jimple_spark_pag_SparkField$object;
struct _jc_soot_jimple_spark_solver_PropMerge$object;

// Typedefs
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$sub_refs	_jc_soot_jimple_spark_solver_PropMerge__241$sub_refs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$sub_nonrefs	_jc_soot_jimple_spark_solver_PropMerge__241$sub_nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$refs	_jc_soot_jimple_spark_solver_PropMerge__241$refs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$nonrefs	_jc_soot_jimple_spark_solver_PropMerge__241$nonrefs;
typedef struct _jc_soot_jimple_spark_solver_PropMerge__241$object	_jc_soot_jimple_spark_solver_PropMerge__241$object;

typedef const struct _jc_soot_jimple_spark_solver_PropMerge__241$vmethods	_jc_soot_jimple_spark_solver_PropMerge__241$vmethods;
typedef const struct _jc_soot_jimple_spark_solver_PropMerge__241$vtable	_jc_soot_jimple_spark_solver_PropMerge__241$vtable;
typedef const struct _jc_soot_jimple_spark_solver_PropMerge__241$vtype	_jc_soot_jimple_spark_solver_PropMerge__241$vtype;

// Constructors
extern void _jc_soot_jimple_spark_solver_PropMerge__241$method$_init$3d64f0b5c6679344(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge__241$object *, struct _jc_soot_jimple_spark_solver_PropMerge$object *, struct _jc_object *, struct _jc_soot_jimple_spark_pag_FieldRefNode$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_soot_jimple_spark_solver_PropMerge__241$method$visit$29be8db3232dadd5(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge__241$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_spark_solver_PropMerge__241$method_info$visit$29be8db3232dadd5;

// Virtual methods structure
struct _jc_soot_jimple_spark_solver_PropMerge__241$vmethods {
	void	(*visit$29be8db3232dadd5)(_jc_env *, struct _jc_soot_jimple_spark_solver_PropMerge__241$object *, struct _jc_soot_jimple_spark_pag_Node$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_spark_solver_PropMerge__241$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_spark_sets_P2SetVisitor$vmethods	soot_jimple_spark_sets_P2SetVisitor;
	_jc_soot_jimple_spark_solver_PropMerge__241$vmethods	soot_jimple_spark_solver_PropMerge__241;
};

// Vtype
struct _jc_soot_jimple_spark_solver_PropMerge__241$vtype {
	_jc_type			type;
	_jc_soot_jimple_spark_solver_PropMerge__241$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropMerge__241$sub_refs {
	struct _jc_object	*val__24field;
	struct _jc_soot_jimple_spark_pag_FieldRefNode$object	*val__24fr;
	struct _jc_soot_jimple_spark_solver_PropMerge$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropMerge__241$refs {
    _jc_soot_jimple_spark_solver_PropMerge__241$sub_refs	soot_jimple_spark_solver_PropMerge__241;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_refs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_spark_solver_PropMerge__241$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_spark_solver_PropMerge__241$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_spark_sets_P2SetVisitor$sub_nonrefs	soot_jimple_spark_sets_P2SetVisitor;
    _jc_soot_jimple_spark_solver_PropMerge__241$sub_nonrefs	soot_jimple_spark_solver_PropMerge__241;
};

// Object instance structure
struct _jc_soot_jimple_spark_solver_PropMerge__241$object {
	_jc_soot_jimple_spark_solver_PropMerge__241$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_spark_solver_PropMerge__241$vtype	*vtype;
	_jc_soot_jimple_spark_solver_PropMerge__241$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_spark_solver_PropMerge__241$vtype _jc_soot_jimple_spark_solver_PropMerge__241$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_spark_solver_PropMerge__241, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_spark_solver_PropMerge__241$class_object;

#endif	/* _JC_soot_jimple_spark_solver_PropMerge__241_H_ */
